@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadPdbqtRole;
-$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.046';
+$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.047';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use HackaMol::PeriodicTable qw(_element_name _trim _qstring_num);
@@ -113,7 +113,7 @@ sub read_pdbqt_atoms {
             carp $message;
         }
     }
-    return (@atoms);
+    return (\@atoms);
 }
 
 no Moose::Role;
@@ -130,7 +130,7 @@ HackaMol::Roles::ReadPdbqtRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
